//############################################################################
//
// EZFB ~ Linux Frame Buffer API ~
//
// by James Lehman
// james@akrobiz.com
//
// began: Feb. 2001
//
// EZFB is intended to give C programmers an easy-to-use library of functions
// for drawing points, lines and strings of characters into the Linux frame
// buffer. It also provides a means of displaying bitmap images on any portion
// of the screen and capturing the contents of any portion of the screen to
// a standard bitmap graphics file. All of this is embodied in a set of
// functions that are polymorphic with regard to the characteristics of the
// frame buffer and the bitmap files used. In other words, it makes no
// difference what the screen height or width is or what the color depth is,
// all of the function calls are the same and will have appropriate and
// predictable effects.
//
// This software is distributed in the hope that it will be useful, but
// without any warranty; without even the implied warranty of merchantability
// or fitness for a particular purpose. See the GNU General Public License
// for more details.
//
//############################################################################

#include "ezfb.h"

//############################################################################
struct ezfb fb = {0};

//############################################################################
int main(int argc, char** argv)
{
    int     key     ,
            xoff = 0,
            yoff = 0;

EZFB_FUNCTION_CALL_0
#if EZFB_API_MESSAGES
    printf("\n\n\n* Program begins:\n");
#endif
    if(argc > 2)
    {
        if(ezfb_name_to_num(argv[2])) // not /dev/fb0
        {
            if(!ezfb_init_named(&fb, argv[2], EZFB_NO_SAVE)) // don't save video RAM
                exit(1);
        }
        else
        {
            if(!ezfb_init_named(&fb, argv[2], EZFB_SAVE_SCREEN))
                exit(1);
        }
    }
    else if(!ezfb_init(&fb, EZFB_SAVE_SCREEN))
    {
        exit(1);
    }

    ezfb_clear_screen           (&fb);
    //ezfb_init_cursor            (&fb);
    ezfb_dump_fb_fix_cursorinfo (&fb);
    ezfb_dump_fb_var_cursorinfo (&fb);
    ezfb_dump_fb_cursorstate    (&fb);

    /*
    while((key = ezfb_get_key()) != EZFB_ESCAPE_KEY) // from ezfb_tty.c
    { // ezfb_get_key() accepts a single key stroke with no return
        switch(key)
        {        
            case EZFB_ARROW_UP   : yoff++;                         
                              ezfb_set_xy_offsets(&fb, xoff, yoff);
                              break;
            //----------------------------------------------------------------
            case EZFB_ARROW_DOWN : yoff--;
                              ezfb_set_xy_offsets(&fb, xoff, yoff);
                              break;
            //----------------------------------------------------------------
            case EZFB_ARROW_RIGHT: xoff++;
                              ezfb_set_xy_offsets(&fb, xoff, yoff);
                              break;
            //----------------------------------------------------------------
            case EZFB_ARROW_LEFT : xoff--;
                              ezfb_set_xy_offsets(&fb, xoff, yoff);
                              break;
            //----------------------------------------------------------------
        }
    }
    */
    ezfb_release(&fb);
#if EZFB_API_MESSAGES
    printf("* Program ends:\n");
#endif
EZFB_FUNCTION_RETURN(!ret)
}

//############################################################################
//////////////////////////////////////////////////////////////////////////////
//############################################################################


